INSERT INTO permissions (module_bit, code, description) VALUES
   ( 1, 'circulate_remaining_permissions', 'Remaining circulation permissions'),
   ( 1, 'override_renewals', 'Override blocked renewals'),
   ( 1, 'overdues_report', 'Execute overdue items report'),
   ( 1, 'force_checkout', 'Force checkout if a limitation exists'),
   ( 1, 'manage_restrictions', 'Manage restrictions for accounts'),
   ( 1, 'manage_bookings', 'Manage item bookings'),
   ( 1, 'manage_checkout_notes', 'Mark checkout notes as seen/not seen'),
   ( 1, 'manage_curbside_pickups', 'Manage curbside pickups'),
   ( 3, 'parameters_remaining_permissions', 'Remaining system parameters permissions'),
   ( 3, 'manage_accounts', 'Manage Account Debit and Credit Types' ),
   ( 3, 'manage_circ_rules', 'Manage circulation rules'),
   ( 3, 'manage_circ_rules_from_any_libraries', 'Manage circ rules for any libraries'),
   ( 3, 'manage_sysprefs', 'Manage system preferences'),
   ( 3, 'manage_libraries', 'Manage libraries and library groups'),
   ( 3, 'manage_itemtypes', 'Manage item types'),
   ( 3, 'manage_auth_values', 'Manage authorized values'),
   ( 3, 'manage_patron_categories', 'Manage patron categories'),
   ( 3, 'manage_patron_attributes', 'Manage extended patron attributes'),
   ( 3, 'manage_transfers', 'Manage library transfer limits and transport cost matrix'),
   ( 3, 'manage_item_circ_alerts', 'Manage item circulation alerts'),
   ( 3, 'manage_cash_registers', 'Add and remove cash registers'),
   ( 3, 'manage_cities', 'Manage cities and towns'),
   ( 3, 'manage_patron_restrictions', 'Manage patron restrictions'),
   ( 3, 'manage_marc_frameworks', 'Manage MARC bibliographic and authority frameworks'),
   ( 3, 'manage_classifications', 'Manage classification sources'),
   ( 3, 'manage_matching_rules', 'Manage record matching rules'),
   ( 3, 'manage_oai_sets', 'Manage OAI sets'),
   ( 3, 'manage_item_search_fields', 'Manage item search fields'),
   ( 3, 'manage_search_engine_config', 'Manage search engine configuration'),
   ( 3, 'manage_marc_overlay_rules', 'Manage MARC overlay rules configuration'),
   ( 3, 'manage_search_targets', 'Manage Z39.50 and SRU servers, OAI repositories configuration'),
   ( 3, 'manage_didyoumean', 'Manage Did you mean? configuration'),
   ( 3, 'manage_column_config', 'Manage column configuration'),
   ( 3, 'manage_sms_providers', 'Manage SMS cellular providers'),
   ( 3, 'manage_audio_alerts', 'Manage audio alerts'),
   ( 3, 'manage_usage_stats', 'Manage usage statistics settings'),
   ( 3, 'manage_mana', 'Manage Mana KB content sharing'),
   ( 3, 'manage_additional_fields', 'Add, edit, or delete additional custom fields for baskets or subscriptions (also requires order_manage or edit_subscription permissions)'),
   ( 3, 'manage_keyboard_shortcuts', 'Manage keyboard shortcuts for the advanced cataloging editor'),
   ( 3, 'manage_smtp_servers', 'Manage SMTP servers configuration'),
   ( 3, 'manage_file_transports', 'Manage file transports configuration'),
   ( 3, 'manage_background_jobs', 'Manage background jobs'),
   ( 3, 'manage_curbside_pickups', 'Manage curbside pickups'),
   ( 3, 'manage_search_filters', 'Manage custom search filters'),
   ( 3, 'manage_identity_providers', 'Manage identity providers'),
   ( 3, 'manage_record_sources', 'Manage record sources'),
   ( 4, 'api_validate_password', 'Validate patron passwords using the API'),
   ( 4, 'delete_borrowers', 'Delete patrons'),
   ( 4, 'edit_borrowers', 'Add, modify and view patron information'),
   ( 4, 'list_borrowers', 'Search, list and view patrons'),
   ( 4, 'merge_borrowers', 'Merge patrons'),
   ( 4, 'send_messages_to_borrowers', 'Send messages to patrons'),
   ( 4, 'view_borrower_infos_from_any_libraries', 'View patron infos from any libraries'),
   ( 6, 'place_holds', 'Place holds for patrons'),
   ( 6, 'modify_holds_priority', 'Modify holds priority'),
   ( 6, 'alter_hold_targets', 'Move holds between items and records'),
   ( 9, 'edit_catalogue', 'Edit catalog (Modify bibliographic/holdings data)'),
   ( 9, 'fast_cataloging', 'Fast cataloging'),
   ( 9, 'advanced_editor', 'Use the advanced cataloging editor (requires edit_catalogue)'),
   ( 9, 'create_shared_macros', 'Create shared macros'),
   ( 9, 'delete_shared_macros', 'Delete shared macros'),
   ( 9, 'edit_items', 'Edit items'),
   ( 9, 'edit_items_restricted', 'Limit item modification to subfields defined in the SubfieldsToAllowForRestrictedEditing preference (please note that edit_item is still required)'),
   ( 9, 'delete_all_items', 'Delete all items at once'),
   ( 9, 'manage_item_groups', 'Create, update and delete item groups, add or remove items from a item groups'),
   ( 9, 'manage_item_editor_templates', 'Update and delete item editor template owned by others'),
   ( 9, 'edit_any_item', 'Edit any item regardless of home library'),
   ( 9, 'edit_locked_records', 'Edit locked records'),
   ( 9, 'set_record_sources', 'Set record source'),
   (10, 'payout', 'Perform account payout action'),
   (10, 'refund', 'Perform account refund action'),
   (10, 'discount', 'Perform account discount action'),
   (10, 'writeoff', 'Write off fines and fees'),
   (10, 'manual_credit', 'Add manual credits to a patron account'),
   (10, 'manual_invoice', 'Add manual invoices to a patron account'),
   (10, 'remaining_permissions', 'Remaining permissions for managing fines and fees'),
   (10, 'edit_accountline_notes', 'Edit accountline notes'),
   (11, 'currencies_manage', 'Manage currencies and exchange rates'),
   (11, 'vendors_manage', 'Manage vendors'),
   (11, 'contracts_manage', 'Manage contracts'),
   (11, 'period_manage', 'Manage budgets'),
   (11, 'budget_manage', 'Manage funds'),
   (11, 'budget_modify', 'Modify funds (can''t create lines, but can modify existing ones)'),
   (11, 'planning_manage', 'Manage budget plannings'),
   (11, 'order_manage', 'Manage baskets and order lines'),
   (11, 'order_manage_all', 'Manage all baskets and order lines, regardless of restrictions on them'),
   (11, 'issue_manage', 'Manage vendor issues'),
   (11, 'group_manage', 'Manage basket groups'),
   (11, 'order_receive', 'Receive orders and manage shipments'),
   (11, 'budget_add_del', 'Add and delete funds (but can''t modify funds)'),
   (11, 'budget_manage_all', 'Manage all funds'),
   (11, 'edi_manage', 'Manage EDIFACT transmissions'),
   (11, 'marc_order_manage', 'Manage MARC ordering'),
   (11, 'reopen_closed_invoices', 'Reopen closed invoices'),
   (11, 'edit_invoices', 'Edit invoices'),
   (11, 'delete_invoices', 'Delete invoices'),
   (11, 'merge_invoices', 'Merge invoices'),
   (11, 'delete_baskets', 'Delete baskets'),
   (12, 'suggestions_create', 'Create purchase suggestions'),
   (12, 'suggestions_manage', 'Manage purchase suggestions'),
   (12, 'suggestions_delete', 'Delete purchase suggestions'),
   (13, 'edit_additional_contents', 'Write additional contents for the OPAC and staff interfaces (news and HTML customizations)'),
   (13, 'label_creator', 'Create printable labels and barcodes from catalog and patron data'),
   (13, 'edit_calendar', 'Define days when the library is closed'),
   (13, 'moderate_comments', 'Moderate patron comments'),
   (13, 'edit_notices', 'Define notices'),
   (13, 'edit_notice_status_triggers', 'Set notice/status triggers for overdue items'),
   (13, 'edit_quotes', 'Edit quotes for quote-of-the-day feature'),
   (13, 'view_system_logs', 'Browse the system logs'),
   (13, 'inventory', 'Perform inventory (stocktaking) of your catalog'),
   (13, 'stage_marc_import', 'Stage MARC records into the reservoir'),
   (13, 'manage_staged_marc', 'Manage staged MARC records, including completing and reversing imports'),
   (13, 'export_catalog', 'Export bibliographic and holdings data'),
   (13, 'import_patrons', 'Import patron data'),
   (13, 'edit_patrons', 'Perform batch modification of patrons'),
   (13, 'delete_anonymize_patrons', 'Delete old borrowers and anonymize circulation history (deletes borrower checkout history)'),
   (13, 'batch_extend_due_dates', 'Perform batch extend due dates'),
   (13, 'batch_modify_holds', 'Perform batch modification of holds'),
   (13, 'batch_upload_patron_images', 'Upload patron images in a batch or one at a time'),
   (13, 'schedule_tasks', 'Schedule tasks to run'),
   (13, 'items_batchmod', 'Perform batch modification of items'),
   (13, 'items_batchmod_restricted', 'Limit batch item modification to subfields defined in the SubfieldsToAllowForRestrictedBatchmod preference (please note that items_batchmod is still required)'),
   (13, 'items_batchdel', 'Perform batch deletion of items'),
   (13, 'manage_csv_profiles', 'Manage CSV export profiles'),
   (13, 'moderate_tags', 'Moderate patron tags'),
   (13, 'rotating_collections', 'Manage rotating collections'),
   (13, 'upload_local_cover_images', 'Upload local cover images'),
   (13, 'manage_patron_lists', 'Add, edit and delete patron lists and their contents'),
   (13, 'records_batchmod', 'Perform batch modification of records (biblios or authorities)'),
   (13, 'marc_modification_templates', 'Manage marc modification templates'),
   (13, 'records_batchdel', 'Perform batch deletion of records (bibliographic or authority)'),
   (13, 'access_files', 'Access to the files stored on the server'),
   (13, 'upload_general_files', 'Upload any file'),
   (13, 'upload_manage', 'Manage uploaded files'),
   (15, 'check_expiration', 'Check the expiration of a serial'),
   (15, 'claim_serials', 'Claim missing serials'),
   (15, 'create_subscription', 'Create a new subscription'),
   (15, 'delete_subscription', 'Delete an existing subscription'),
   (15, 'edit_subscription', 'Edit an existing subscription'),
   (15, 'receive_serials', 'Serials receiving'),
   (15, 'renew_subscription', 'Renew a subscription'),
   (15, 'routing', 'Routing'),
   (15, 'superserials', 'Manage subscriptions from any branch (only applies when IndependentBranches is used)'),
   (16, 'execute_reports', 'Execute SQL reports'),
   (16, 'create_reports', 'Create SQL reports'),
   (16, 'delete_reports', 'Delete SQL reports'),
   (18, 'manage_courses', 'Add, edit and delete courses'),
   (18, 'add_reserves', 'Add course reserves'),
   (18, 'delete_reserves', 'Remove course reserves'),
   (19, 'manage', 'Manage plugins ( install / uninstall )'),
   (19, 'tool', 'Use tool plugins'),
   (19, 'report', 'Use report plugins'),
   (19, 'admin', 'Use administrative plugins'),
   (19, 'configure', 'Configure plugins'),
   (20, 'create_public_lists', 'Create public lists'),
   (20, 'delete_public_lists', 'Delete public lists'),
   (20, 'edit_public_lists', 'Edit public lists'),
   (20, 'edit_public_list_contents', 'Edit public list contents'),
   (20, 'use_public_lists', 'Use public lists'),
   (21, 'edit_templates', 'Create and update club templates'),
   (21, 'edit_clubs', 'Create and update clubs'),
   (21, 'enroll', 'Enroll patrons in clubs'),
   (23, 'self_checkin_module', 'Log into the self check-in module'),
   (23, 'self_checkout_module', 'Perform self checkout at the OPAC. It should be used for the patron matching the AutoSelfCheckID'),
   (24, 'manage_rotas', 'Create, edit and delete rotas'),
   (24, 'manage_rota_items', 'Add and remove items from rotas'),
   (25, 'anonymous_refund', 'Perform refund actions from cash registers'),
   (25, 'cashup', 'Perform cash register cashup action'),
   (25, 'takepayment', 'Access the point of sale page and take payments'),
   (26, 'manage_problem_reports', 'Manage OPAC problem reports'),
   (27, 'manage_recalls', 'Manage recalls for patrons')
;
